// Copyright © 2018 Ken'ichiro Oyama <k1lowxb@gmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

package util

import (
	"fmt"
	"github.com/dustin/go-humanize"
	"math"
	"strconv"
)

// Bytes convert string numeric to a human readable "byte".
func Bytes(v string) string {
	parsed, err := strconv.ParseUint(v, 10, 64)
	if err != nil {
		return v
	}
	return humanize.Bytes(parsed)
}

// Usec convert float64 to a human readable "microseconds"
func Usec(v float64) string {
	vint := int64(v)
	return fmt.Sprintf("%v us    ", humanize.Comma(vint))
}

// UsecPerSec convert float64 to a human readable "microseconds/second"
func UsecPerSec(v float64) string {
	vint := int64(v)
	return fmt.Sprintf("%v us/sec", humanize.Comma(vint))
}

// Round ...
func Round(f float64) float64 {
	return math.Floor(f + 0.5)
}
